@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int auspec(long*, long*, double*, double*, double*, double*);
 
 /* rtimsac72.dll subroutine */ int auspec(i1,i2,d1,d2,d3,d4)
@@ -7,9 +9,10 @@ extern int auspec(long*, long*, double*, double*, double*, double*);
 	long *i1,*i2;
 
 {
-	extern int auspecf_(long*, long*, double*, double*, double*, double*);
+	extern int F77_NAME(auspecf) (long*, long*, double*, double*, double*, double*);
 
-	auspecf_(i1,i2,d1,d2,d3,d4);
+	F77_CALL(auspecf) (i1,i2,d1,d2,d3,d4);
 
 	return 0;
 }
+
