@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int bispec(long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
 /* rtimsac74.dll subroutine */ int bispec(i1,i2,d1,d2,d3,d4,d5,d6,d7,d8,d9)
@@ -7,9 +9,9 @@ extern int bispec(long*,long*,double*,double*,double*,double*,double*,double*,do
 	long *i1,*i2;
 
 {
-	extern int bispecf_(long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
+	extern int F77_NAME(bispecf)(long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-	bispecf_(i1,i2,d1,d2,d3,d4,d5,d6,d7,d8,d9);
+	F77_CALL(bispecf) (i1,i2,d1,d2,d3,d4,d5,d6,d7,d8,d9);
 
 	return 0;
 }
