@@ -129,10 +129,10 @@ cc	READ(5,2) (CYY(I),I=1,LAGH3)
 cc	WRITE(6,11130)
 cc	WRITE(6,11111) N,LAGH0
       AN=N
-      IFPL=3.0D-00*DSQRT(AN)
+cc      IFPL=3.0D-00*DSQRT(AN)
 cc	IFPL=MIN0(IFPL,49,LAGH0)
-      IFPL=MIN0(IFPL,(MJ1-1),LAGH0)
-      IFPL1=IFPL+1
+cc      IFPL=MIN0(IFPL,(MJ1-1),LAGH0)
+cc      IFPL1=IFPL+1
 C     INITIAL AUTOREGRESSIVE MODEL FITTING
 cc	CALL NSICP(CYY,IFPL1,N,A,MO,SD,AIC)
       NA=(IFPL1*(IFPL1+1)/2)
@@ -292,9 +292,9 @@ cc  999 STOP
     2 FORMAT(4D20.10)
     6 FORMAT(//1H ,21HCANONICAL CORRELATION)
     7 FORMAT(/1H ,'NUMBER OF PRESENT AND FUTURE VARIABLES',2X,
-     A	     'M1=',I5)
+     A'M1=',I5)
     8 FORMAT(/1H ,'NUMBER OF PRESENT AND PAST VARIABLES',4X,
-     A	     'M2=',I5)
+     A'M2=',I5)
     9 FORMAT(/1H ,'DATA LENGTH=N=',I6)
    35 FORMAT(/1H ,'FUTURE SET CANONICAL WEIGHTS, ROWWISE')
    49 FORMAT(/1H ,5X,8HORDER(P),4X,11HCANONICAL R,3X,9HR-SQUARED,3X,
@@ -302,12 +302,12 @@ cc  999 STOP
    50 FORMAT(1H ,10X,I3,4X,F8.4,4X,F8.3,7X,F8.2,4X,I6,3X,F10.4)
  4410 FORMAT(/1H ,'MINIMUM DIC(P) =',F12.2,1X,'ATTAINED AT P=',I5)
  1130 FORMAT(/1H ,'STRUCTURAL CHARACTERISTIC VECTOR',
-     A	     ' (H(I),I=1,P)')
+     A' (H(I),I=1,P)')
 11111 FORMAT(/1H ,'INITIAL AUTO REGRESSIVE MODEL FITTING ',
-     A	     'BY THE MINIMUM AIC PROCEDURE. / N=',I5,',LAGH0=',I5)
+     A'BY THE MINIMUM AIC PROCEDURE. / N=',I5,',LAGH0=',I5)
 11112 FORMAT(1H ,5X,'THE VALUES OF CHI-SQUARE AND DIC (P) ',
-     A	     'CORRESPONDING TO CANONICAL R=','1.000 ',
-     A	     'SHOULD BE IGNORED')
+     A'CORRESPONDING TO CANONICAL R=','1.000 ',
+     A'SHOULD BE IGNORED')
 11130 FORMAT(/1H ,'PROGRAM 74.1.1. CANARM')
       END
 C
@@ -520,7 +520,7 @@ cc  699 F(JJ0)=BL
       RETURN
 26100 FORMAT(/1H ,16X,'SD(M)',15X,'AIC(M)',13X,'A(M)')
 26101 FORMAT(1H ,4X,'M',11X,'INNOVATION',10X,'AIC(M)=    ',8X,
-     A	    'PARTIAL AUTO-')
+     A'PARTIAL AUTO-')
 cc  261 FORMAT(1H ,16X,'   VARIANCE',9X,'N*DLOG(SD(M))+2*M',
 cc     A      '  CORRELATION    ',
 cc     A      'PARTIAL CORRELATION (LINES SHOW +SD AND +2SD)')
