@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int decomp(double*, long*, long*, double*, double*, double*, double*, double*, double*, long*, double*);
 
 /* rdecomp subroutine */ int decomp(d1,i1,i2,d2,d3,d4,d5,d6,d7,i3,d8)
@@ -7,10 +9,9 @@ extern int decomp(double*, long*, long*, double*, double*, double*, double*, dou
 	long *i1,*i2,*i3;
 
 {
-	extern int decompf_(double*, long*, long*, double*, double*, double*, double*, double*, double*, long*, double*);
+	extern int F77_NAME(decompf) (double*, long*, long*, double*, double*, double*, double*, double*, double*, long*, double*);
   
-	decompf_(d1,i1,i2,d2,d3,d4,d5,d6,d7,i3,d8);
+	F77_CALL(decompf) (d1,i1,i2,d2,d3,d4,d5,d6,d7,i3,d8);
 
 	return 0;
 }
-
