@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int fftcor(long*, long*, long*, long*, long*, double*, double*, double*, double*, double*, double*, double*, double*, double*);
 
 /* rtimsac72.dll subroutine */ int fftcor(i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9)
@@ -7,9 +9,9 @@ extern int fftcor(long*, long*, long*, long*, long*, double*, double*, double*,
 	long *i1,*i2,*i3,*i4,*i5;
 
 {
-	extern int fftcorf_(long*, long*, long*, long*, long*, double*, double*, double*, double*, double*, double*, double*, double*, double*);
+	extern int F77_NAME(fftcorf) (long*, long*, long*, long*, long*, double*, double*, double*, double*, double*, double*, double*, double*, double*);
 
-	fftcorf_(i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9);
+	F77_CALL(fftcorf) (i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9);
 
 	return 0;
 }
