@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int mlomar(double*,long*,long*,double*,long*,long*,long*,long*,double*,double*,long*,long*,long*,double*,long*,double*,long*,double*,double*,double*,long*,long*);
 
 /* rtimsac78.dll subroutine */ int mlomar(d1,i1,i2,d2,i3,i4,i5,i6,d3,d4,i7,i8,i9,d5,i10,d6,i11,d7,d8,d9,i12,i13)
@@ -8,9 +10,9 @@ extern int mlomar(double*,long*,long*,double*,long*,long*,long*,long*,double*,do
 
 {
 
-	extern int mlomarf_(double*,long*,long*,double*,long*,long*,long*,long*,double*,double*,long*,long*,long*,double*,long*,double*,long*,double*,double*,double*,long*,long*);
+	extern int F77_NAME(mlomarf) (double*,long*,long*,double*,long*,long*,long*,long*,double*,double*,long*,long*,long*,double*,long*,double*,long*,double*,double*,double*,long*,long*);
 
-	mlomarf_(d1,i1,i2,d2,i3,i4,i5,i6,d3,d4,i7,i8,i9,d5,i10,d6,i11,d7,d8,d9,i12,i13);
+	F77_CALL(mlomarf) (d1,i1,i2,d2,i3,i4,i5,i6,d3,d4,i7,i8,i9,d5,i10,d6,i11,d7,d8,d9,i12,i13);
 
 	return 0;
 
