@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int mulbar(double*,long*,long*,double*,long*,double*,double*,double*,double*,double*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
 /* rtimsac78.dll subroutine */ int mulbar(d1,i1,i2,d2,i3,d3,d4,d5,d6,d7,i4,d8,d9,d10,d11,d12,d13,d14,d15,d16,d17)
@@ -7,9 +9,9 @@ extern int mulbar(double*,long*,long*,double*,long*,double*,double*,double*,doub
 	long *i1,*i2,*i3,*i4;
 
 {
-	extern int mulbarf_(double*,long*,long*,double*,long*,double*,double*,double*,double*,double*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
+	extern int F77_NAME(mulbarf) (double*,long*,long*,double*,long*,double*,double*,double*,double*,double*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-	mulbarf_(d1,i1,i2,d2,i3,d3,d4,d5,d6,d7,i4,d8,d9,d10,d11,d12,d13,d14,d15,d16,d17);
+	F77_CALL(mulbarf) (d1,i1,i2,d2,i3,d3,d4,d5,d6,d7,i4,d8,d9,d10,d11,d12,d13,d14,d15,d16,d17);
 
 	return 0;
 }
