@@ -1,4 +1,5 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
 
 struct Rcomplex {
 	double r;
@@ -14,9 +15,9 @@ extern int mulfrf(long*, long*, long*, long*, long*, double*, struct Rcomplex*,
 	struct Rcomplex *d2;
 
 {
-	extern int mulfrff_(long*, long*, long*, long*, long*, double*, struct Rcomplex*, double*, double*, double*, double*, double*, double*, double*);
+	extern int F77_NAME(mulfrff) (long*, long*, long*, long*, long*, double*, struct Rcomplex*, double*, double*, double*, double*, double*, double*, double*);
 
-	mulfrff_(i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9);
+	F77_CALL(mulfrff) (i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9);
 
 	return 0;
 }
