@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int mulnos(long*, long*, long*, double*, double*, double*, double*, double*);
 
 /* rtimsac72.dll subroutine */ int mulnos(i1,i2,i3,d1,d2,d3,d4,d5)
@@ -7,9 +9,9 @@ extern int mulnos(long*, long*, long*, double*, double*, double*, double*, doubl
 	long *i1,*i2,*i3;
 
 {
-	extern int mulnosf_(long*, long*, long*, double*, double*, double*, double*, double*);
+	extern int F77_NAME(mulnosf) (long*, long*, long*, double*, double*, double*, double*, double*);
 
-	mulnosf_(i1,i2,i3,d1,d2,d3,d4,d5);
+	F77_CALL(mulnosf) (i1,i2,i3,d1,d2,d3,d4,d5);
 
 	return 0;
 }
