@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int ngsmth(double*, long*, long*, double*, double*, long*, double*, double*, long*, double*, float*, double*, long*, long*, long*, long*);
 
 int ngsmth(d1,i1,i2,d2,d3,i3,d4,d5,i4,d6,f1,d7,i5,i6,i7,i8)
@@ -8,9 +10,9 @@ int ngsmth(d1,i1,i2,d2,d3,i3,d4,d5,i4,d6,f1,d7,i5,i6,i7,i8)
 	long   *i1,*i2,*i3,*i4,*i5,*i6,*i7,*i8;
 
 {
-	extern int ngsmthf_(double*, long*, long*, double*, double*, long*, double*, double*, long*, double*, float*, double*, long*, long*, long*, long*);
+	extern int F77_NAME(ngsmthf) (double*, long*, long*, double*, double*, long*, double*, double*, long*, double*, float*, double*, long*, long*, long*, long*);
 
-	ngsmthf_(d1,i1,i2,d2,d3,i3,d4,d5,i4,d6,f1,d7,i5,i6,i7,i8);
+	F77_CALL(ngsmthf) (d1,i1,i2,d2,d3,i3,d4,d5,i4,d6,f1,d7,i5,i6,i7,i8);
 
 	return 0;
 }
