@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int raspec(long*, long*, long*, double*, double*, double*, double*);
 
 /* rtimsac72.dll subroutine */ int raspec(i1,i2,i3,d1,d2,d3,d4)
@@ -7,9 +9,9 @@ extern int raspec(long*, long*, long*, double*, double*, double*, double*);
 	long *i1,*i2,*i3;
 
 {
-	extern int raspecf_(long*, long*, long*, double*, double*, double*, double*);
+	extern int F77_NAME(raspecf) (long*, long*, long*, double*, double*, double*, double*);
 
-	raspecf_(i1,i2,i3,d1,d2,d3,d4);
+	F77_CALL(raspecf) (i1,i2,i3,d1,d2,d3,d4);
 
 	return 0;
 }
