@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int simcon(long*,long*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
 /* rtimsac74.dll subroutine */ int simcon(i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9,d10)
@@ -7,9 +9,9 @@ extern int simcon(long*,long*,long*,long*,long*,double*,double*,double*,double*,
 	long *i1,*i2,*i3,*i4,*i5;
 
 {
-	extern int simconf_(long*,long*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
+	extern int F77_NAME(simconf)  (long*,long*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-	simconf_(i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9,d10);
+	F77_CALL(simconf) (i1,i2,i3,i4,i5,d1,d2,d3,d4,d5,d6,d7,d8,d9,d10);
 
 	return 0;
 }
