@@ -1,5 +1,6 @@
-
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int tvspc(long*, long*, long*, long*, long*, double*, double*, double*, double*);
 
 int tvspc(i1,i2,i3,i4,i5,d1,d2,d3,d4)
@@ -8,10 +9,9 @@ int tvspc(i1,i2,i3,i4,i5,d1,d2,d3,d4)
 	long *i1,*i2,*i3,*i4,*i5;
 
 {
-	extern int tvspcf_(long*, long*, long*, long*, long*, double*, double*, double*, double*);
+	extern int F77_NAME(tvspcf) (long*, long*, long*, long*, long*, double*, double*, double*, double*);
 
-	tvspcf_(i1,i2,i3,i4,i5,d1,d2,d3,d4);
+	F77_CALL(tvspcf) (i1,i2,i3,i4,i5,d1,d2,d3,d4);
 
 	return 0;
 }
-
