@@ -1,4 +1,6 @@
 #include "timsac.h"
+#include <R_ext/RS.h>
+
 extern int xsarma(double*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
 /* rtimsac78.dll subroutine */ int xsarma(d1,i1,i2,i3,d2,d3,d4,d5,d6,d7,d8,d9,d10)
@@ -7,9 +9,9 @@ extern int xsarma(double*,long*,long*,long*,double*,double*,double*,double*,doub
 	long *i1,*i2,*i3;
 
 {
-	extern int xsarmaf_(double*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
+	extern int F77_NAME(xsarmaf) (double*,long*,long*,long*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-	xsarmaf_(d1,i1,i2,i3,d2,d3,d4,d5,d6,d7,d8,d9,d10);
+	F77_CALL(xsarmaf) (d1,i1,i2,i3,d2,d3,d4,d5,d6,d7,d8,d9,d10);
 
 	return 0;
 }
